@@ -2,7 +2,13 @@ import platform
 import sys
 
 
+PLATFORM = None
+
+
 def get_system():
+    global PLATFORM
+    if PLATFORM is not None:
+        return PLATFORM
     if sys.platform == u'win32':
         platform_ = u'win'
     elif sys.platform == u'darwin':
@@ -14,4 +20,5 @@ def get_system():
             platform_ = u'arm'
         else:
             platform_ = u'nix'
+    PLATFORM = platform_
     return platform_
